@@ -234,6 +234,14 @@ class anim_text:
                 cur_frame = bpy.context.scene.frame_current
                 
                 text.data.body = ('{0:.'+str(fix_place)+'f}').format(fixed_data[cur_frame-1]) + ' ' + label
+
+        else:
+            def recalculate_text(scene):
+                text = ob
+                cur_frame = bpy.context.scene.frame_current
+                
+                text.data.body = data + ' ' + label
                     
 
-            bpy.app.handlers.frame_change_pre.append(recalculate_text)
\ No newline at end of file
+            bpy.app.handlers.frame_change_pre.append(recalculate_text)
+
